@@ -26,6 +26,8 @@ class ImportLocationsTask(Task):
                 obj_dict = {}
                 for key in m.keys():
                     if key in location_fields:
+                        if isinstance(m[key], basestring):
+                            m[key] = m[key].strip()
                         obj_dict[key] = m[key]
 
                 # Add other fields
